package envoy.event;

/**
 * Signifies to the client that the handshake failed for the attached
 * reason.<br>
 * <br>
 * Project: <strong>envoy-common</strong><br>
 * File: <strong>HandshakeRejectionEvent.java</strong><br>
 * Created: <strong>28 Jan 2020</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy Common v0.3-alpha
 */
public class HandshakeRejectionEvent extends Event<String> {

	/**
	 * Select this value if a given password hash or user was incorrect.
	 */
	public static final String WRONG_PASSWORD_OR_USER = "password or user were entered incorrectly";

	/**
	 * Select this value if the handshake could not be completed for some reason.
	 */
	public static final String INTERNAL_ERROR = "the process could not be finished as an internal error occurred";

	private static final long serialVersionUID = 0L;

	/**
	 * Creates an instance of {@link HandshakeRejectionEvent} with an empty reason.
	 *
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejectionEvent() { super(""); }

	/**
	 * Creates an instance of {@link HandshakeRejectionEvent}.
	 *
	 * @param reason the reason why the handshake was rejected
	 * @since Envoy Common v0.3-alpha
	 */
	public HandshakeRejectionEvent(String reason) { super(reason); }
}
